// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: FigRRect.java
// Classes: FigRRect
// Original Author: ics125b spring 1996
// $Id: FigRRect.java,v 1.2 1997/01/24 02:56:37 jrobbins Exp $

package uci.graphedit;


import java.applet.*;
import java.awt.*;
import java.io.*;
import java.util.*;

/** Primitive Fig to draw rounded rectangles on a LayerDiagram */

public class FigRRect extends FigRect {

  protected int _radius = 16;
  
  public FigRRect(int x, int y, int w, int h, Color line, int r) {
    super(x, y, w, h, line);
  }
  
  /** Construct a new FigRRect w/ the given position, size, and attributes */
  public FigRRect(int x, int y, int w, int h, Hashtable gAttrs) {
    super(x, y, w, h, gAttrs);
  }

  /** Construct a new FigRRect w/ the given position, size, line color,
   * and fill color*/
  public FigRRect(int x, int y, int w, int h, Color line, Color fill) {
    super(x, y, w, h, line, fill);
  }

  public void radius(int r) { _radius = r; }
  public int radius() { return _radius; }

  public Object getGraphicAttribute(String k) {
    if (k.equals("Radius")) return new Integer(radius());
    else return super.getGraphicAttribute(k);
  }

  public void setGraphicAttribute(String k, Object v) {
    if (k.equals("Radius")) radius(((Integer)v).intValue());
    else super.setGraphicAttribute(k, v);
  }

  
  /** Draw this FigRRect */
  public void draw(Graphics g) {
    int rx = position().x;
    int ry = position().y;
    int new_x, new_y, new_w, new_h;
    int r = radius();

    /* Compensate for negative width and height (for drag) */
    if (objectWidth > 0) { new_x = rx; new_w = objectWidth; }
    else { new_x = rx + objectWidth; new_w = -objectWidth; }
    
    if (objectHeight > 0) { new_y = ry; new_h = objectHeight; }
    else { new_y = ry + objectHeight; new_h = -objectHeight; }
    
    if (objectFillColor != null) {
      g.setColor(objectFillColor);
      g.fillRoundRect(new_x, new_y, new_w, new_h, r, r);
    }
    g.setColor(objectLineColor);
    g.drawRoundRect(new_x, new_y, new_w, new_h, r, r);
  }




} /* end of FigRRect class */




